@@ -63,7 +63,9 @@ will go through a deprecation cycle.
 The goal of this package is to parse well-formed regular expressions
 correctly. A secondary goal is not to blow up on ill-formed regular
 expressions. The correct identification and characterization of
-ill-formed regular expressions is B<not> a goal of this package.
+ill-formed regular expressions is B<not> a goal of this package, nor is
+the consistent parsing of ill-formed regular expressions from release to
+release.
 
 This policy attempts to track features in development releases as well
 as public releases. However, features added in a development release and
@@ -72,6 +74,53 @@ and any functionality relating to such features B<will be removed>. The
 issue here is the potential re-use (with different semantics) of syntax
 that did not make it into the production release.
 
+From time to time the Perl regular expression engine changes in ways
+that change the parse of a given regular expression. When these changes
+occur, C<PPIx::Regexp> will be changed to produce the more modern parse.
+Known examples of this include:
+
+=over
+
+=item C<$(> no longer interpolates as of Perl 5.005, per C<perl5005delta>.
+
+Newer Perls seem to parse this as C<qr{$}> (i.e. and end-of-string or
+newline assertion) followed by an open parenthesis, and that is what
+C<PPIx::Regexp> does.
+
+=item C<$)> and C<$|> also seem to parse as the C<$> assertion
+
+followed by the relevant meta-character, though I have no documentation
+reference for this.
+
+=item C<@+> and C<@-> no longer interpolate as of Perl 5.9.4
+
+per C<perl594delta>. Subsequent Perls treat C<@+> as a quantified
+literal and C<@-> as two literals, and that is what C<PPIx::Regexp>
+does. Note that subscripted references to these arrays B<do>
+interpolate, and are so parsed by C<PPIx::Regexp>.
+
+=item Only space and horizontal tab are whitespace as of Perl 5.23.4
+
+when inside a bracketed character class inside an extended bracketed
+character class, per C<perl5234delta>. Formerly any white space
+character parsed as whitespace. This change in C<PPIx::Regexp> will be
+reverted if the change in Perl does not make it into Perl 5.24.0.
+
+=back
+
+There are very probably other examples of this. When they come to light
+they will be documented as producing the modern parse, and the code
+modified to produce this parse if necessary.
+
+The functionality that parses string literals (the C<parse> argument to
+C<new()>) was introduced in version [%% next_version $$], and should be
+considered experimental. It is a bit of a kluge in any case, especially
+in the appropriateness of class names to this use. But the actual
+parsing of a Perl string literal is not too different than the parsing
+of an C<s///> replacement string, so I thought that if someone wanted
+a string literal parse badly enough to deal with the kluginess I could
+provide it fairly easily.
+
 =head1 METHODS
 
 This class provides the following public methods. Methods not documented
@@ -88,11 +137,13 @@ use warnings;
 use base qw{ PPIx::Regexp::Node };
 
 use PPIx::Regexp::Lexer ();
+use PPIx::Regexp::StringTokenizer;
 use PPIx::Regexp::Token::Modifier ();	# For its modifier manipulations.
-use PPIx::Regexp::Util qw{ __instance };
+use PPIx::Regexp::Tokenizer;
+use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.041';
+our $VERSION = '0.047';
 
 =head2 new
 
@@ -102,9 +153,12 @@ This method instantiates a C<PPIx::Regexp> object from a string, a
 L<PPI::Token::QuoteLike::Regexp|PPI::Token::QuoteLike::Regexp>, a
 L<PPI::Token::Regexp::Match|PPI::Token::Regexp::Match>, or a
 L<PPI::Token::Regexp::Substitute|PPI::Token::Regexp::Substitute>.
-Honestly, any L<PPI::Element|PPI::Element> will do, but only the three
+Honestly, any L<PPI::Element|PPI::Element> will work, but only the three
 Regexp classes mentioned previously are likely to do anything useful.
 
+Whatever form the argument takes, it is assumed to consist entirely of a
+valid match, substitution, or C<< qr<> >> string.
+
 Optionally you can pass one or more name/value pairs after the regular
 expression. The possible options are:
 
@@ -134,7 +188,7 @@ statements), do something like
 
  my $re = PPIx::Regexp->new( 'm/ foo /',
      default_modifiers => [ '/smx', '-/x' ] );
-`
+
 =item encoding name
 
 This option specifies the encoding of the regular expression. This is
@@ -145,6 +199,55 @@ string before it tokenizes it. For example:
      encoding => 'iso-8859-1',
  );
 
+=item parse parse_type
+
+This option specifies what kind of parse is to be done. Possible values
+are C<'regex'>, C<'string'>, or C<'guess'>. Any value but C<'regex'> is
+experimental.
+
+If C<'regex'> is specified, the first argument is expected to be a valid
+regex, and parsed as though it were.
+
+If C<'string'> is specified, the first argument is expected to be a
+valid string literal and parsed as such. The return is still a
+C<PPIx::Regexp> object, but the
+L<regular_expression()|/regular_expression> and L<modifier()|/modifier>
+methods return nothing, and the L<replacement()|/replacement> method
+returns the content of the string.
+
+If C<'guess'> is specified, this method will try to guess what the first
+argument is. If the first argument is a L<PPI::Element|PPI::Element>,
+the guess will reflect the PPI parse. But the guess can be wrong if the
+first argument is a string representing an unusually-delimited regex.
+For example, C<'guess'> will parse C<"foo"> as a string, but Perl will
+parse it as a regex if preceded by a regex binding operator (e.g. C<$x
+=~ "foo">), as shown by
+
+ perl -MO=Deparse -e '$x =~ "foo"'
+
+which prints
+
+ $x =~ /foo/u
+
+under Perl 5.22.0.
+
+The default is C<'regex'>.
+
+=item postderef boolean
+
+This option is passed on to the tokenizer, where it specifies whether
+postfix dereferences are recognized in interpolations and code. This
+experimental feature was introduced in Perl 5.19.5. The default is the
+value of C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF>, which is false
+by default.
+
+If postfix dereferencing becomes mainstream, the default value of
+C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF> will become true.
+
+Note that if L<PPI|PPI> starts unconditionally recognizing postfix
+dereferences, this argument will immediately become ignored, and will be
+put through a deprecation cycle and removed.
+
 =item trace number
 
 If greater than zero, this option causes trace output from the parse.
@@ -168,7 +271,15 @@ is it supported.
 
 	$errstr = undef;
 
-	my $tokenizer = PPIx::Regexp::Tokenizer->new(
+	my $tokenizer_class = __choose_tokenizer_class( $content, \%args )
+	    or do {
+	    $errstr = ref $content ?
+		sprintf '%s not supported', ref $content :
+		"Unknown parse type '$args{parse}'";
+	    return;
+	};
+
+	my $tokenizer = $tokenizer_class->new(
 	    $content, %args ) or do {
 	    $errstr = PPIx::Regexp::Tokenizer->errstr();
 	    return;
@@ -319,7 +430,7 @@ will be returned; index 0 represents the regular expression's
 delimiters, and index 1 represents the replacement string's delimiters,
 which may be undef. For example,
 
- print PPIx::Regexp->new('s{foo}<bar>')-delimiters(1);
+ print PPIx::Regexp->new('s{foo}<bar>')->delimiters(1);
  # prints '<>'
 
 If the object was not initialized with a valid regexp of some sort, the
@@ -352,6 +463,10 @@ attempt succeeded.
 
 # defined above, just after sub new.
 
+sub explain {
+    return;
+}
+
 =head2 failures
 
  print "There were ", $re->failures(), " parse failures\n";
@@ -667,7 +782,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2015 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
