@@ -42,9 +42,9 @@ use Scalar::Util qw{ blessed looks_like_number };
 
 use PPIx::Regexp;
 use PPIx::Regexp::Tokenizer;
-use PPIx::Regexp::Util qw{ __instance };
+use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
 
 =head2 new
 
@@ -76,6 +76,11 @@ specified, it is passed through to
 L<< PPIx::Regexp->new()|PPIx::Regexp/new >>. It also causes an
 C<Encode::encode> to be done on any parse content dumped.
 
+=item explain boolean
+
+If true, this option causes the C<explain()> output of each object to be
+dumped.
+
 =item indent number
 
 This argument is the number of additional spaces to indent each level of
@@ -103,6 +108,11 @@ If true, this option causes the C<perl_version_introduced> and
 C<perl_version_removed> values associated with each object dumped to be
 displayed.
 
+=item postderef boolean
+
+If true, postfix dereferences are recognized in code and interpolations.
+See the tokenizer's L<new()|PPIx::Regexp::Tokenizer/new> for details.
+
 =item significant boolean
 
 If true, this option causes only significant elements to be dumped.
@@ -154,6 +164,7 @@ ignored.
 {
 
     my %default = (
+	explain	=> 0,
 	indent	=> 2,
 	margin	=> 0,
 	ordinal	=> 0,
@@ -175,8 +186,10 @@ ignored.
 	    source => $re,
 	};
 
-	exists $args{default_modifiers}
-	    and $self->{default_modifiers} = $args{default_modifiers};
+	foreach my $key ( qw{ default_modifiers parse postderef } ) {
+	    exists $args{$key}
+		and $self->{$key} = $args{$key};
+	}
 
 	foreach my $key ( keys %default ) {
 	    $self->{$key} = exists $args{$key} ?
@@ -196,9 +209,11 @@ ignored.
 	} elsif ( ref $re && ! __instance( $re, 'PPI::Element' ) ) {
 	    croak "Do not know how to dump ", ref $re;
 	} elsif ( $self->{tokens} ) {
+	    my $tokenizer_class = __choose_tokenizer_class( $re, \%args )
+		or croak 'Unsupported data type';
 	    $self->{object} =
-		PPIx::Regexp::Tokenizer->new( $re, %args )
-		    or Carp::croak( PPIx::Regexp::Tokenizer->errstr() );
+		$tokenizer_class->new( $re, %args )
+		    or Carp::croak( $tokenizer_class->errstr() );
 	} else {
 	    $self->{object} =
 		PPIx::Regexp->new( $re, %args )
@@ -286,7 +301,7 @@ sub _safe {
 }
 
 sub _safe_version {
-    my ( $self, $version ) = @_;
+    my ( undef, $version ) = @_;	# Invocant unused
     return defined $version ? "'$version'" : 'undef';
 }
 
@@ -300,7 +315,7 @@ sub _nav {
 }
 
 sub _perl_version {
-    my ( $self, $elem ) = @_;
+    my ( undef, $elem ) = @_;		# Invocant unused
 
     my $rslt = $elem->perl_version_introduced() . ' <= $]';
     if ( my $max = $elem->perl_version_removed() ) {
@@ -340,15 +355,20 @@ sub _tokens_dump {
 
 sub _format_default_modifiers {
     my ( $self, $subr, $elem ) = @_;
-    my $default_modifiers = $self->{default_modifiers} || [];
-    @{ $default_modifiers }
-	or return sprintf '%-8s( %s );', $subr, $self->_safe( $elem );
-    return sprintf '%-8s( %s, default_modifiers => %s );', $subr,
-	$self->_safe( $elem ), $self->_safe( $default_modifiers );
+    my @arg = $self->_safe( $elem );
+    foreach my $attr ( qw{ default_modifiers parse postderef } ) {
+	defined ( my $val = $self->{$attr} )
+	    or next;
+	'ARRAY' eq ref $val
+	    and not @{ $val }
+	    and next;
+	push @arg, "$attr => @{[ $self->_safe( $val ) ]}";
+    }
+    return sprintf '%-8s( %s );', $subr, join ', ', @arg;
 }
 
 sub _format_modifiers_dump {
-    my ( $self, $elem ) = @_;
+    my ( undef, $elem ) = @_;		# Invocant unused
     my %mods = $elem->modifiers();
     my @accum;
     $mods{match_semantics}
@@ -382,6 +402,23 @@ sub _tokens_test {
     return @rslt;
 }
 
+sub PPIx::Regexp::Element::__PPIX_DUMPER__dump_explanation {
+    my ( $self, undef, $line ) = @_;	# $dumper unused
+    my @expl = $self->explain()
+	or return $line;
+    1 == @expl
+	and return "$line\t$expl[0]";
+    wantarray
+	or return sprintf "%s\t%s", $line, join '; ', @expl;
+    ( my $blank = $line ) =~ s/\S/ /smxg;
+    my @rslt;
+    foreach my $splain ( @expl ) {
+	push @rslt, "$line\t$splain";
+	$line = $blank;
+    }
+    return @rslt;
+}
+
 sub PPIx::Regexp::__PPIX_DUMPER__test {
     my ( $self, $dumper ) = @_;
 
@@ -414,9 +451,16 @@ sub PPIx::Regexp::Node::__PPIX_DUMPER__dump {
 
     my @rslt = ref $self;
     $self->isa( 'PPIx::Regexp' )
-	and $rslt[-1] .= "\tfailures=" . $self->failures();
+	and $rslt[-1] .= $dumper->{verbose}
+	    ? sprintf "\tfailures=%d\tmax_capture_number=%d",
+		$self->failures(), $self->max_capture_number()
+	    : sprintf "\tfailures=%d", $self->failures();
     $dumper->{perl_version}
 	and $rslt[-1] .= "\t" . $dumper->_perl_version( $self );
+    $dumper->{explain}
+	and push @rslt, $self->__PPIX_DUMPER__dump_explanation(
+	    $dumper, pop @rslt );
+
     my $indent = ' ' x $dumper->{indent};
     foreach my $elem ( $self->children() ) {
 	push @rslt, map { $indent . $_ } $elem->__PPIX_DUMPER__dump( $dumper );
@@ -450,6 +494,16 @@ sub PPIx::Regexp::Node::__PPIX_DUMPER__test {
     return @rslt;
 }
 
+sub _format_value {
+    my ( $val ) = @_;
+    defined $val
+	or return 'undef';
+    $val =~ m/ \A [0-9]+ \z /smx
+	and return $val;
+    $val =~ s/ (?= [\\"] ) /\\/smxg;
+    return qq{"$val"};
+}
+
 {
 
     my %dflt = (
@@ -473,12 +527,10 @@ sub PPIx::Regexp::Node::__PPIX_DUMPER__test {
 	$dumper->{perl_version}
 	    and push @rslt, $dumper->_perl_version( $self );
 	if ( $dumper->{verbose} ) {
-	    foreach my $method ( qw{ number name } ) {
+	    foreach my $method ( qw{ number name max_capture_number } ) {
 		$self->can( $method ) or next;
-		my $val = $self->$method;
-		push @rslt, defined $val ?
-		    "$method=$val" :
-		    "$method undef";
+		push @rslt, sprintf '%s=%s', $method, _format_value(
+		    $self->$method() );
 	    }
 	    foreach my $method ( qw{ can_be_quantified is_quantifier } ) {
 ##		is_case_sensitive
@@ -489,6 +541,19 @@ sub PPIx::Regexp::Node::__PPIX_DUMPER__test {
 		and push @rslt, $dumper->_format_modifiers_dump(
 		$self->type( 0 ) );
 	}
+
+	foreach my $method ( 'start', undef, 'finish' ) {
+	    my $ele = defined $method ? $self->$method() : $self
+		or next;
+	    if ( defined ( my $err = $ele->error() ) ) {
+		push @rslt, $err;
+	    }
+	}
+	@rslt = ( join "\t", @rslt );
+	$dumper->{explain}
+	    and push @rslt, $self->__PPIX_DUMPER__dump_explanation(
+		$dumper, pop @rslt );
+
 	@rslt = ( join( "\t", @rslt ) );
 	my $indent = ' ' x $dumper->{indent};
 	foreach my $elem ( $self->children() ) {
@@ -553,13 +618,15 @@ sub PPIx::Regexp::Tokenizer::__PPIX_DUMPER__test {
 sub PPIx::Regexp::Token::__PPIX_DUMPER__dump {
     my ( $self, $dumper ) = @_;
 
-    not $dumper->{significant} or $self->significant() or return;
+    not $dumper->{significant}
+	or $self->significant()
+	or return;
 
     my @rslt = ( ref $self, $dumper->_safe( $self ) );
 
     if ( defined( my $err = $self->error() ) ) {
 
-	push @rslt, $err;
+	return join "\t", @rslt, $err;
 
     } else {
 
@@ -598,8 +665,14 @@ sub PPIx::Regexp::Token::__PPIX_DUMPER__dump {
 	    }
 
 	}
+
+	@rslt = ( join "\t", @rslt );
+
+	$dumper->{explain}
+	    and push @rslt, $self->__PPIX_DUMPER__dump_explanation(
+		$dumper, pop @rslt );
+	return @rslt;
     }
-    return join( "\t", @rslt );
 }
 
 sub PPIx::Regexp::Token::__PPIX_DUMPER__test {
@@ -667,7 +740,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
