@@ -42,7 +42,7 @@ use Scalar::Util qw{ refaddr weaken };
 
 use PPIx::Regexp::Constant qw{ MINIMUM_PERL TOKEN_UNKNOWN };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
 
 =head2 ancestor_of
 
@@ -121,6 +121,51 @@ sub descendant_of {
     return $node->ancestor_of( $self );
 }
 
+=head2 explain
+
+This method returns a brief explanation of what the element does. The
+return will be either a string or C<undef> in scalar context, but may be
+multiple values or an empty array in list context.
+
+This method should be considered experimental. What it returns may
+change without notice as my understanding of what all the pieces/parts
+of a Perl regular expression evolves. The worst case is that it will
+prove entirely infeasible to implement satisfactorily, in which case it
+will be put through a deprecation cycle and retracted.
+
+=cut
+
+sub explain {
+    my ( $self ) = @_;
+    my $explanation = $self->__explanation();
+    my $content = $self->content();
+    if ( my $main = $self->main_structure() ) {
+	my $delim = $main->delimiters();
+	$delim = qr{ \\ (?= [\Q$delim\E] ) }smx;
+	$content =~ s/$delim//smxg;
+    }
+    if ( defined( my $splain = $explanation->{$content} ) ) {
+	return $splain;
+    }
+    return $self->__no_explanation();
+}
+
+# Return explanation hash
+sub __explanation {
+    $PPIx::Regexp::NO_EXPLANATION_FATAL
+	and confess 'Neither explain() nor __explanation() overridden';
+    return {};
+}
+
+# Called if no explanation available
+sub __no_explanation {
+##  my ( $self ) = @_;		# Invocant unused
+    my $msg = sprintf q<No explanation>;
+    $PPIx::Regexp::NO_EXPLANATION_FATAL
+	and confess $msg;
+    return $msg;
+}
+
 =head2 error
 
  say $token->error();
@@ -136,6 +181,26 @@ sub error {
     return $self->{error};
 }
 
+=head2 in_regex_set
+
+This method returns a true value if the invocant is contained in an
+extended bracketed character class (also known as a regex set), and a
+false value otherwise. This method returns true if the invocant is a
+L<PPIx::Regexp::Structure::RegexSet|PPIx::Regexp::Structure::RegexSet>.
+
+=cut
+
+sub in_regex_set {
+    my ( $self ) = @_;
+    my $ele = $self;
+    while ( 1 ) {
+	$ele->isa( 'PPIx::Regexp::Structure::RegexSet' )
+	    and return 1;
+	$ele = $ele->parent()
+	    or last;
+    }
+    return 0;
+}
 
 =head2 is_quantifier
 
@@ -151,6 +216,28 @@ greediness token is possible.
 
 sub is_quantifier { return; }
 
+=head2 main_structure
+
+This method returns the
+L<PPIx::Regexp::Structure::Main|PPIx::Regexp::Structure::Main> that
+contains the element. In practice this will be a
+L<PPIx::Regexp::Structure::Regexp|PPIx::Regexp::Structure::Regexp> or a
+L<PPIx::Regexp::Structure::Replacement|PPIx::Regexp::Structure::Replacement>,
+
+If the element is not contained in any such structure, C<undef> is
+returned. This will happen if the element is a
+L<PPIx::Regexp|PPIx::Regexp> or one of its immediate children.
+
+=cut
+
+sub main_structure {
+    my ( $self ) = @_;
+    while ( $self = $self->parent()
+	    and not $self->isa( 'PPIx::Regexp::Structure::Main' ) ) {
+    }
+    return $self;
+}
+
 =head2 modifier_asserted
 
  $token->modifier_asserted( 'i' )
@@ -438,33 +525,9 @@ sub nav {
 
 }
 
-# $self->__impose_defaults( $arg, \%default );
-#
-# This method can be called in __PPIX_TOKEN__post_make() to supply
-# defaults for attributes. It returns nothing.
-#
-# The arguments are hash references, which are taken in left-to-right
-# order, with the, with the first extant value being used.
-
-sub __impose_defaults {
-    my ( $self, @args ) = @_;
-    foreach my $arg ( @args ) {
-	ref $arg eq 'HASH'
-	    or next;
-	foreach my $key ( keys %{ $arg } ) {
-	    exists $self->{$key}
-		or $self->{$key} = $arg->{$key};
-	}
-    }
-    return;
-}
-
 # Bless into TOKEN_UNKNOWN, record error message, return 1.
 sub __error {
     my ( $self, $msg ) = @_;
-    $self->isa( 'PPIx::Token::Node' )
-	and confess 'Programming error - __error() must be overridden',
-	    ' for class ', ref $self;
     defined $msg
 	or $msg = 'Was ' . ref $self;
     $self->{error} = $msg;
@@ -474,10 +537,22 @@ sub __error {
 
 # Called by the lexer to record the capture number.
 sub __PPIX_LEXER__record_capture_number {
-    my ( $self, $number ) = @_;
+    my ( undef, $number ) = @_;		# Invocant unused
     return $number;
 }
 
+# Called by the lexer to rebless
+sub __PPIX_ELEM__rebless {
+    my ( $class, $self ) = @_;		# %arg unused
+    $self ||= {};
+    bless $self, $class;
+    delete $self->{error};
+    defined $self->{error}
+	and return 1;
+    delete $self->{error};
+    return 0;
+}
+
 sub DESTROY {
     $_[0]->_parent( undef );
     return;
@@ -498,7 +573,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
