@@ -35,7 +35,17 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Node };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
+
+sub explain {
+    my ( $self ) = @_;
+    my $first = $self->schild( 0 )
+	or return $self->__no_explanation();
+    my $last = $self->schild( -1 )
+	or return $self->__no_explanation();
+    return sprintf q<Characters between '%s' and '%s' inclusive>,
+	$first->content(), $last->content();
+}
 
 1;
 
@@ -52,7 +62,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
