@@ -52,7 +52,7 @@ use PPIx::Regexp::Constant qw{ STRUCTURE_UNKNOWN };
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
 
 sub _new {
     my ( $class, @args ) = @_;
@@ -103,6 +103,10 @@ sub _new {
 	    $val->_parent( $self );
 	}
     }
+
+    @{ $self->{finish} }
+	or $self->{error} = 'Missing end delimiter';
+
     return $self;
 }
 
@@ -127,6 +131,17 @@ sub elements {
     }
 }
 
+sub explain {
+    my ( $self ) = @_;
+    if ( my $type = $self->type() ) {
+	return $type->explain();
+    }
+    if ( my $start = $self->start() ) {
+	return $start->explain();
+    }
+    return $self->__no_explanation();
+}
+
 =head2 finish
 
  my $elem = $struct->finish();
@@ -236,7 +251,7 @@ sub type {
 
 # Check for things like (?$foo:...) or (?$foo)
 sub _check_for_interpolated_match {
-    my ( $class, $brkt, $args ) = @_;
+    my ( undef, $brkt, $args ) = @_;	# Invocant unused
 
     # Everything we are interested in begins with a literal '?' followed
     # by an interpolation.
@@ -256,12 +271,13 @@ sub _check_for_interpolated_match {
 	&& $args->[2]->content() eq ':' ) {
 
 	# Rebless the '?' as a GroupType::Modifier.
-	bless $args->[0], 'PPIx::Regexp::Token::GroupType::Modifier';
-	# Note that we do _not_ want __PPIX_TOKEN__post_make here.
+	PPIx::Regexp::Token::GroupType::Modifier->__PPIX_ELEM__rebless(
+	    $args->[0] );
 
 	# Rebless the ':' as a GroupType, just so it does not look like
 	# something to match against.
-	bless $args->[2], 'PPIx::Regexp::Token::GroupType';
+	PPIx::Regexp::Token::GroupType->__PPIX_ELEM__rebless(
+	    $args->[2] );
 
 	# Shove our three significant tokens into the type.
 	push @{ $brkt->{type} }, splice @{ $args }, 0, 3;
@@ -289,13 +305,15 @@ sub _check_for_interpolated_match {
 	    && $args->[4]->content() eq ':' ) {
 
 	    # Rebless the '?' as a GroupType::Modifier.
-	    bless $args->[0], 'PPIx::Regexp::Token::GroupType::Modifier';
-	    # Note that we do _not_ want __PPIX_TOKEN__post_make here.
+	    PPIx::Regexp::Token::GroupType::Modifier->__PPIX_ELEM__rebless(
+		$args->[0] );
 
 	    # Rebless the '-' and ':' as GroupType, just so they do not
 	    # look like something to match against.
-	    bless $args->[2], 'PPIx::Regexp::Token::GroupType';
-	    bless $args->[4], 'PPIx::Regexp::Token::GroupType';
+	    PPIx::Regexp::Token::GroupType->__PPIX_ELEM__rebless(
+		$args->[2] );
+	    PPIx::Regexp::Token::GroupType->__PPIX_ELEM__rebless(
+		$args->[4] );
 
 	    # Shove our five significant tokens into the type.
 	    push @{ $brkt->{type} }, splice @{ $args }, 0, 5;
@@ -319,8 +337,8 @@ sub _check_for_interpolated_match {
     }
 
     # Rebless the '?' as a GroupType::Modifier.
-    bless $args->[0], 'PPIx::Regexp::Token::GroupType::Modifier';
-    # Note that we do _not_ want __PPIX_TOKEN__post_make here.
+    PPIx::Regexp::Token::GroupType::Modifier->__PPIX_ELEM__rebless(
+	$args->[0] );
 
     # Shove all the contents of $args into type, using splice to leave
     # @{ $args } empty after we do this.
@@ -354,7 +372,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
