@@ -35,7 +35,12 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Structure };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
+
+sub explain {
+    my ( $self ) = @_;
+    return sprintf q<Capture group number %s>, $self->number();
+}
 
 =head2 name
 
@@ -86,7 +91,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
