@@ -36,7 +36,7 @@ use base qw{ PPIx::Regexp::Structure };
 
 use PPIx::Regexp::Util qw{ __instance };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
 
 sub _new {
     my ( $class, @args ) = @_;
@@ -50,6 +50,13 @@ sub _new {
     return $class->SUPER::_new( \%brkt, @args );
 }
 
+sub explain {
+    my ( $self ) = @_;
+    $self->negated()
+	and return 'Inverted character class';
+    return 'Character class';
+}
+
 =head2 negated
 
  $class->negated() and print "Class is negated\n";
@@ -66,7 +73,7 @@ sub negated {
 
 # Called by the lexer to record the capture number.
 sub __PPIX_LEXER__record_capture_number {
-    my ( $self, $number ) = @_;
+    my ( undef, $number ) = @_;		# Invocant unused
     return $number;
 }
 
@@ -85,7 +92,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
