@@ -34,19 +34,37 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Structure };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
 
 sub can_be_quantified {
     return;
 }
 
+sub explain {
+    my ( $self ) = @_;
+    my $content = $self->content();
+    if ( $content =~ m/ \A [{] ( .*? ) [}] \z /smx ) {
+	my $quant = $1;
+	my ( $lo, $hi ) = split qr{ , }smx, $quant;
+	defined $hi
+	    and '' ne $hi
+	    and return "match $lo to $hi times";
+	$quant =~ m/ , \z /smx
+	    and return "match $lo or more times";
+	$lo =~ m/ [^0-9] /smx
+	    and return "match $lo times";
+	return "match exactly $lo times";
+    }
+    return $self->SUPER::explain();
+}
+
 sub is_quantifier {
     return 1;
 }
 
 # Called by the lexer to record the capture number.
 sub __PPIX_LEXER__record_capture_number {
-    my ( $self, $number ) = @_;
+    my ( undef, $number ) = @_;		# Invocant unused
     return $number;
 }
 
@@ -65,7 +83,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
