@@ -36,7 +36,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Structure::Main };
 
-our $VERSION = '0.041';
+our $VERSION = '0.047';
 
 sub can_be_quantified { return; }
 
@@ -62,6 +62,10 @@ sub capture_names {
     return ( sort keys %name );
 }
 
+sub explain {
+    return 'Regular expression';
+}
+
 =head2 max_capture_number
 
  print "Highest used capture number ",
@@ -110,7 +114,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2015 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
