@@ -38,10 +38,14 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Structure::Main };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
 
 sub can_be_quantified { return; }
 
+sub explain {
+    return 'Replacement string or expression';
+}
+
 1;
 
 __END__
@@ -57,7 +61,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
