@@ -34,7 +34,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Structure };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
 
 sub __PPIX_LEXER__finalize {
     my ( $self ) = @_;
@@ -68,7 +68,6 @@ sub __PPIX_LEXER__finalize {
 	    $kid->content() eq '|' or next;
 	    --$alternations >= 0 and next;
 	    $kid->__error( 'Too many alternatives for switch' );
-	    $rslt++;
 	}
     } else {
 	# If we could not figure out how many alternations were allowed,
@@ -80,7 +79,7 @@ sub __PPIX_LEXER__finalize {
 
     # Delegate to the superclass to finalize our children, now that we
     # have finished messing with them.
-    $rslt = $self->SUPER::__PPIX_LEXER__finalize();
+    $rslt += $self->SUPER::__PPIX_LEXER__finalize();
 
     return $rslt;
 }
@@ -100,7 +99,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
