@@ -43,7 +43,7 @@ use base qw{ PPIx::Regexp::Token::CharClass };
 
 use PPIx::Regexp::Constant qw{ COOKIE_CLASS COOKIE_REGEX_SET MINIMUM_PERL };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -70,6 +70,37 @@ sub perl_version_introduced {
     return '5.006';
 }
 
+{
+
+    my %explanation = (
+	'[:alnum:]'	=> 'Any alphanumeric character',
+	'[:alpha:]'	=> 'Match alphabetic',
+	'[:ascii:]'	=> 'Any character in the ASCII character set',
+	'[:blank:]'	=> 'A GNU extension, equal to a space or a horizontal tab ("\\t")',
+	'[:cntrl:]'	=> 'Any control character',
+	'[:digit:]'	=> 'Any decimal digit ("[0-9]")',
+	'[:graph:]'	=> 'Any printable character, excluding a space',
+	'[:lower:]'	=> 'Any lowercase character',
+	'[:print:]'	=> 'Any printable character',
+	'[:punct:]'	=> 'Any graphical character excluding "word" characters',
+	'[:space:]'	=> 'Any whitespace character',
+	'[:upper:]'	=> 'Any uppercase character',
+	'[:word:]'	=> 'A Perl extension, equivalent to "\\w"',
+	'[:xdigit:]'	=> 'Any hexadecimal digit',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+
+    sub __no_explanation {
+##	my ( $self ) = @_;		# Invocant unused
+	my $msg = sprintf q<Unknown POSIX character class>;
+	return $msg;
+    }
+
+}
+
 {
 
     my %class = (
@@ -77,7 +108,7 @@ sub perl_version_introduced {
     );
 
     sub __PPIX_TOKENIZER__regexp {
-	my ( $class, $tokenizer, $character ) = @_;
+	my ( undef, $tokenizer ) = @_;	# Invocant, $character unused
 
 	$tokenizer->cookie( COOKIE_CLASS )
 	    or $tokenizer->cookie( COOKIE_REGEX_SET )
@@ -111,7 +142,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
