@@ -39,7 +39,48 @@ use PPIx::Regexp::Constant qw{
     COOKIE_CLASS MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
 };
 
-our $VERSION = '0.025';
+our $VERSION = '0.047';
+
+{
+
+    my %kind_of_match = (
+	p	=> 'with',
+	P	=> 'without',
+    );
+
+    my %explanation = (
+	'.'	=> 'Match any character',
+	'\\C'	=> 'Match a single octet (removed in 5.23.0)',
+	'\\D'	=> 'Match any character but a decimal digit',
+	'\\H'	=> 'Match a non-horizontal-white-space character',
+	'\\N'	=> 'Match any character but a new-line character',
+	'\\R'	=> 'Match a generic new-line character',
+	'\\S'	=> 'Match non-white-space character',
+	'\\V'	=> 'Match a non-vertical-white-space character',
+	'\\W'	=> 'Match non-word character',
+	'\\X'	=> 'Match a Unicode extended grapheme cluster',
+	'\\d'	=> 'Match decimal digit',
+	'\\h'	=> 'Match a horizontal-white-space character',
+	'\\s'	=> 'Match white-space character',
+	'\\v'	=> 'Match a vertical-white-space character',
+	'\\w'	=> 'Match word character',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+
+    sub explain {
+	my ( $self ) = @_;
+	if ( $self->content() =~ m/ \A \\ ( [Pp] ) [{] ( .* ) [}] \z /smx ) {
+	    return sprintf
+		q<Match character %s Unicode or custom property '%s'>,
+		$kind_of_match{$1}, $2;
+	}
+	return $self->SUPER::explain();
+    }
+
+}
 
 ##=head2 is_case_sensitive
 ##
@@ -82,7 +123,7 @@ our $VERSION = '0.025';
     sub _is_case_sensitive {
 	my ( $self ) = @_;
 	my $content = $self->content();
-	$content =~ m/ \A \\ p { ( .* ) } /smxi
+	$content =~ m/ \A \\ p [{] ( .* ) [}] /smxi
 	    or return 0;
 	$content = lc $1;
 	$content =~ s/ \A ^ //smx;
@@ -99,14 +140,14 @@ our $VERSION = '0.025';
 {
 
     my %introduced = (
-	'\h'	=> '5.009005',	# Before this, parsed as 'h'
-	'\v'	=> '5.009005',	# Before this, parsed as 'v'
-	'\H'	=> '5.009005',	# Before this, parsed as 'H'
-	'\N'	=> '5.011',	# Before this, an error.
-	'\V'	=> '5.009005',	# Before this, parsed as 'V'
-	'\R'	=> '5.009005',
-	'\C'	=> '5.006',
-	'\X'	=> '5.006',
+	'\\h'	=> '5.009005',	# Before this, parsed as 'h'
+	'\\v'	=> '5.009005',	# Before this, parsed as 'v'
+	'\\H'	=> '5.009005',	# Before this, parsed as 'H'
+	'\\N'	=> '5.011',	# Before this, an error.
+	'\\V'	=> '5.009005',	# Before this, parsed as 'V'
+	'\\R'	=> '5.009005',
+	'\\C'	=> '5.006',
+	'\\X'	=> '5.006',
     );
 
     sub perl_version_introduced {
@@ -128,8 +169,19 @@ our $VERSION = '0.025';
 
 }
 
+{
+    my %removed	 = (
+	'\\C'	=> '5.023',	# Before this, matched an octet
+    );
+
+    sub perl_version_removed {
+	my ( $self ) = @_;
+	return $removed{ $self->content() };
+    }
+}
+
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( undef, $tokenizer, $character ) = @_;
 
     my $in_class = $tokenizer->cookie( COOKIE_CLASS );
 
@@ -150,7 +202,10 @@ sub __PPIX_TOKENIZER__regexp {
 	    # As of Perl 5.11.5, [\N] is a fatal error.
 	    '\\N' eq $match
 		and return $tokenizer->make_token(
-		    $accept, TOKEN_UNKNOWN );
+		    $accept, TOKEN_UNKNOWN, {
+			    error	=> '\\N invalid inside character class',
+			},
+		    );
 	    # \R is not recognized inside a character class. It
 	    # eventually ends up as a literal.
 	    '\\R' eq $match and return;
@@ -176,7 +231,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2012 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
