@@ -50,21 +50,32 @@ use PPI::Document;
 use PPIx::Regexp::Constant qw{ COOKIE_REGEX_SET };
 use PPIx::Regexp::Util qw{ __instance };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
 
-sub _new {
-    my ( $class, $content ) = @_;
-    ref $class and $class = ref $class;
+use constant TOKENIZER_ARGUMENT_REQUIRED => 1;
+use constant VERSION_WHEN_IN_REGEX_SET => undef;
 
-    my $self = {};
-    if ( __instance( $content, 'PPI::Document' ) ) {
-	$self->{ppi} = $content;
-    } elsif ( ref $content ) {
-	return;
-    } else {
-	$self->{content} = $content;
+sub __new {
+    my ( $class, $content, %arg ) = @_;
+
+    defined $arg{perl_version_introduced}
+	or $arg{perl_version_introduced} = '5.005';
+
+    my $self = $class->SUPER::__new( $content, %arg );
+
+    # TODO sort this out, since Token::Interpolation is a subclass, and
+    # those are legal in regex sets
+    if ( $arg{tokenizer}->cookie( COOKIE_REGEX_SET ) ) {
+	my $ver = $self->VERSION_WHEN_IN_REGEX_SET()
+	    or return $self->__error( 'Code token not valid in Regex set' );
+	$self->{perl_version_introduced} < $ver
+	    and $self->{perl_version_introduced} = $ver;
     }
-    bless $self, $class;
+
+    $arg{tokenizer}->__recognize_postderef( $self )
+	and $self->{perl_version_introduced} < 5.019005
+	and $self->{perl_version_introduced} = '5.019005';
+
     return $self;
 }
 
@@ -79,9 +90,8 @@ sub content {
     }
 }
 
-sub perl_version_introduced {
-    my ( $self ) = @_;
-    return $self->{perl_version_introduced};
+sub explain {
+    return 'Perl expression';
 }
 
 =head2 ppi
@@ -107,29 +117,19 @@ sub ppi {
 # sub can_be_quantified { return };
 
 {
+    no warnings qw{ qw };	## no critic (ProhibitNoWarnings)
 
-    my %default = (
-	perl_version_introduced	=> '5.005',	# When (?{...}) introduced.
-    );
+    my %accept = map { $_ => 1 } qw{ $ $# @ % & * };
 
-    sub __PPIX_TOKEN__post_make {
-	my ( $self, $tokenizer, $arg ) = @_;
-
-	$self->__impose_defaults( $arg, \%default );
-
-	# If we're manufacturing objects directly (which is UNSUPPORTED,
-	# but used in t/version.t) we may not have a $tokenizer.
-	$tokenizer
-	    and $tokenizer->cookie( COOKIE_REGEX_SET )
-	    and $self->__error( 'Code token not valid in Regex set' );
-
-	return;
+    # Say what casts are accepted, since not all are in am
+    # interpolation.
+    sub __postderef_accept_cast {
+	return \%accept;
     }
-
 }
 
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( undef, $tokenizer, $character ) = @_;
 
     $character eq '{' or return;
 
@@ -154,7 +154,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
