@@ -34,11 +34,21 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::GroupType };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+{
+    my %explanation = (
+	'?|'	=> 'Re-use capture group numbers',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+}
+
 sub perl_version_introduced {
     return '5.009005';
 }
@@ -62,7 +72,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
