@@ -43,11 +43,25 @@ use base qw{ PPIx::Regexp::Token::GroupType };
 
 use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+{
+
+    my %explanation = (
+	'??'	=> 'Evaluate code, use as regexp at this point',
+	'?p'	=> 'Evaluate code, use as regexp at this point (removed in 5.9.5)',
+	'?'		=> 'Evaluate code. Always matches.',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+
+}
+
 {
     my %perl_version_introduced = (
 	'?'	=> '5.005',
@@ -112,7 +126,7 @@ sub __defining_string {
 }
 
 sub __match_setup {
-    my ( $class, $tokenizer ) = @_;
+    my ( undef, $tokenizer ) = @_;	# Invocant unused
     $tokenizer->expect( qw{ PPIx::Regexp::Token::Code } );
     return;
 }
@@ -132,7 +146,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
