@@ -35,7 +35,18 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::GroupType };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
+
+{
+
+    my %explanation = (
+	'?'	=> q<Match one of the following '|'-delimited alternatives>,
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+}
 
 sub perl_version_introduced {
 #   my ( $self ) = @_;
@@ -82,7 +93,7 @@ sub __defining_string {
 }
 
 sub __match_setup {
-    my ( $class, $tokenizer ) = @_;
+    my ( undef, $tokenizer ) = @_;	# Invocant unused
     $tokenizer->expect( qw{ PPIx::Regexp::Token::Condition } );
     return;
 }
@@ -103,7 +114,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
