@@ -34,12 +34,26 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::Code };
 
+use Carp qw{ confess };
 use PPI::Document;
 use PPIx::Regexp::Constant qw{
     COOKIE_CLASS COOKIE_REGEX_SET TOKEN_LITERAL MINIMUM_PERL
 };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
+
+use constant VERSION_WHEN_IN_REGEX_SET => '5.017009';
+
+sub __new {
+    my ( $class, $content, %arg ) = @_;
+
+    defined $arg{perl_version_introduced}
+	or $arg{perl_version_introduced} = MINIMUM_PERL;
+
+    my $self = $class->SUPER::__new( $content, %arg );
+
+    return $self;
+}
 
 # Return true if the token can be quantified, and false otherwise
 # This can be quantified because it might interpolate a quantifiable
@@ -89,7 +103,7 @@ sub ppi {
 # Match the beginning of an interpolation.
 
 my $interp_re =
-	qr{ \A (?: [\@\$]? \$ [-\w&`'+^./\\";%=~:?!\@\$<>\[\]\{\},#] |
+	qr{ \A (?= [\@\$]? \$ [-\w&`'+^./\\";%=~:?!\@\$<>\[\]\{\},#] |
 		   \@ [\w\{] )
 	}smx;
 
@@ -112,7 +126,7 @@ my %allow_subscript_based_on_cast_symbol = (
 );
 
 sub _interpolation {
-    my ( $class, $tokenizer, $character, $in_regexp ) = @_;
+    my ( $class, $tokenizer, undef, $in_regexp ) = @_;	# $character unused
 
     # If the regexp does not interpolate, bail now.
     $tokenizer->interpolates() or return;
@@ -123,7 +137,7 @@ sub _interpolation {
     }
 
     # Make sure we start off plausibly
-    $tokenizer->find_regexp( $interp_re )
+    defined $tokenizer->find_regexp( $interp_re )
 	or return;
 
     # See if PPI can figure out what we have
@@ -161,21 +175,6 @@ sub _interpolation {
 	    ) or return;
 	    push @accum, $next;
 	} elsif ( $next->isa( 'PPI::Structure::Block' ) ) {
-
-=begin comment
-
-	    local $_ = $next->content();
-	    if ( m< \A { / } >smx ) {
-		push @accum, 3;	# Number of characters to accept.
-	    } else {
-##		$allow_subscript = $accum[-1]->content() ne '$#';
-		push @accum, $next;
-	    }
-
-=end comment
-
-=cut
-
 	    push @accum, $next;
 	} else {
 	    return;
@@ -205,6 +204,13 @@ sub _interpolation {
 	    $next->content() eq '->' or last;
 	    push @subscr, $next;
 	    $next = $next->next_sibling() or last;
+
+	    # postderef was introduced in 5.19.5, per perl5195delta.
+	    if ( my $deref = $tokenizer->__recognize_postderef(
+		    __PACKAGE__, $next ) ) {
+		push @accum, @subscr, $deref;
+		last;
+	    }
 	}
 
 	# Accept only a subscript
@@ -236,6 +242,16 @@ sub _interpolation {
     return $length;
 }
 
+{
+    no warnings qw{ qw };	## no critic (ProhibitNoWarnings)
+
+    my %accept = map { $_ => 1 } qw{ $ $# @ };
+
+    sub __postderef_accept_cast {
+	return \%accept;
+    }
+}
+
 {
 
     my %allowed = (
@@ -268,7 +284,7 @@ sub _interpolation {
 # Return true if we think a curly-bracketed subscript is really a
 # subscript, rather than a quantifier.
 sub _curly {
-    my ( $class, @kids ) = @_;
+    my ( undef, @kids ) = @_;		# Invocant unused
 
     # If the first child is a word, and either it is an only child or
     # the next child is the fat comma operator, we accept it as a
@@ -280,11 +296,17 @@ sub _curly {
 	    and return 1;
     }
 
-    # If we have exactly one child which is a symbol, we accept it as a
-    # subscript.
-    @kids == 1
-	and $kids[0]->isa( 'PPI::Token::Symbol' )
-	and return 1;
+    # If the first child is a symbol,
+    if ( @kids && $kids[0]->isa( 'PPI::Token::Symbol' ) ) {
+	# Accept it if it is the only child
+	@kids == 1
+	    and return 1;
+	# Accept it if there are exactly two children and the second is
+	# a subscript.
+	@kids == 2
+	    and $kids[1]->isa( 'PPI::Structure::Subscript' )
+	    and return 1;
+    }
 
     # We reject anything else.
     return;
@@ -293,7 +315,7 @@ sub _curly {
 # Return true if we think a square-bracketed subscript is really a
 # subscript, rather than a character class.
 sub _square {
-    my ( $class, @kids ) = @_;
+    my ( undef, @kids ) = @_;		# Invocant unused
 
     # We expect to have either a number or a symbol as the first
     # element.
@@ -304,28 +326,6 @@ sub _square {
     return;
 }
 
-{
-
-    my %default = (
-	perl_version_introduced	=> MINIMUM_PERL,
-    );
-
-    sub __PPIX_TOKEN__post_make {
-	my ( $self, $tokenizer, $arg ) = @_;
-
-	# If we're manufacturing objects directly (which is UNSUPPORTED,
-	# but used in t/version.t) we may not have a $tokenizer.
-	$tokenizer
-	    and $tokenizer->cookie( COOKIE_REGEX_SET )
-	    and $self->{perl_version_introduced} = '5.017009';
-
-	$self->__impose_defaults( $arg, \%default );
-
-	return;
-    }
-
-}
-
 # Alternate classes for the sigils, depending on whether we are in a
 # character class (index 1) or not (index 0).
 my %sigil_alternate = (
@@ -338,7 +338,7 @@ sub __PPIX_TOKENIZER__regexp {
 
     exists $sigil_alternate{$character} or return;
 
-    if ( my $accept = _interpolation( $class, $tokenizer, $character, 1 ) ) {
+    if ( my $accept = $class->_interpolation( $tokenizer, $character, 1 ) ) {
 	return $accept;
     }
 
@@ -353,7 +353,7 @@ sub __PPIX_TOKENIZER__repl {
 
     exists $sigil_alternate{$character} or return;
 
-    if ( my $accept = _interpolation( $class, $tokenizer, $character, 0 ) ) {
+    if ( my $accept = $class->_interpolation( $tokenizer, $character, 0 ) ) {
 	return $accept;
     }
 
@@ -440,7 +440,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
