@@ -38,11 +38,15 @@ use PPIx::Regexp::Constant qw{
     COOKIE_CLASS COOKIE_REGEX_SET MINIMUM_PERL TOKEN_UNKNOWN
 };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+sub explain {
+    return 'Literal character';
+}
+
 sub perl_version_introduced {
     my ( $self ) = @_;
     exists $self->{perl_version_introduced}
@@ -111,13 +115,18 @@ my %regex_set_operator = map { $_ => 1 } qw{ & + | - ^ ! };
 # made characters that generated warnings when escaped, in preparation
 # for adding them. When they actually get added, I will have to add back
 # the trinary operator. Sigh.
-my $white_space_re = 'qr< \A [\t\n\cK\f\r ] >smx';
+# my $white_space_re = 'qr< \A [\t\n\cK\f\r ] >smx';
+#
+# The extended white space characters came back in Perl 5.21.1.
+my $white_space_re = $] >= 5.008 ?
+'qr< \\A [\\t\\n\\cK\\f\\r \\N{U+0085}\\N{U+200E}\\N{U+200F}\\N{U+2028}\\N{U+2029}]+ >smx' :
+'qr< \\A [\\t\\n\\cK\\f\\r ]+ >smx';
 $white_space_re = eval $white_space_re;  ## no critic (ProhibitStringyEval)
 
 my %regex_pass_on = map { $_ => 1 } qw{ [ ] ( ) $ \ };
 
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character, $char_type ) = @_;
+    my ( undef, $tokenizer, $character ) = @_;	# Invocant, $char_type unused
 
     if ( $tokenizer->cookie( COOKIE_REGEX_SET ) ) {
 	# If we're inside a regex set no literals are allowed, but not
@@ -129,7 +138,14 @@ sub __PPIX_TOKENIZER__regexp {
 
 	my $accept;
 
-	$accept = $tokenizer->find_regexp( $white_space_re )
+	# As of 5.23.4, only space and horizontal tab are legal white
+	# space inside a bracketed class inside an extended character
+	# class
+	$accept = $tokenizer->find_regexp(
+	    $tokenizer->cookie( COOKIE_CLASS ) ?
+		qr{ \A [ \t] }smx :
+		$white_space_re
+	)
 	    and return $tokenizer->make_token(
 		$accept, 'PPIx::Regexp::Token::Whitespace' );
 
@@ -410,7 +426,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
