@@ -35,7 +35,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-our $VERSION = '0.028';
+our $VERSION = '0.047';
 
 # Return true if the token can be quantified, and false otherwise
 sub can_be_quantified { return };
@@ -55,14 +55,28 @@ is, if it is '*', '+', or '?'.
 =cut
 
 sub could_be_quantifier {
-    my ( $class, $string ) = @_;
+    my ( undef, $string ) = @_;		# Invocant unused
     return $quantifier{$string};
 }
 
-sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+{
 
-    $tokenizer->prior( 'can_be_quantified' )
+    my %explanation = (
+	'*'	=> 'match zero or more times',
+	'+'	=> 'match one or more times',
+	'?'	=> 'match zero or one time',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+
+}
+
+sub __PPIX_TOKENIZER__regexp {
+    my ( undef, $tokenizer, $character ) = @_;
+
+    $tokenizer->prior_significant_token( 'can_be_quantified' )
 	or return;
 
     return $quantifier{$character};
@@ -83,7 +97,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2012 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
