@@ -39,7 +39,36 @@ use base qw{ PPIx::Regexp::Token };
 
 use PPIx::Regexp::Constant qw{ COOKIE_REGEX_SET MINIMUM_PERL };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
+
+sub __new {
+    my ( $class, $content, %arg ) = @_;
+
+    defined $arg{perl_version_introduced}
+	or $arg{perl_version_introduced} = 
+	( grep { 127 < ord } split qr{}, $content )
+	? '5.021001'
+	: MINIMUM_PERL;
+
+    return $class->SUPER::__new( $content, %arg );
+}
+
+sub explain {
+    my ( $self ) = @_;
+    my $parent;
+    if (
+	$parent = $self->parent()
+	    and $parent->isa( 'PPIx::Regexp' )
+    ) {
+	    return 'Not significant';
+    } elsif ( $self->in_regex_set() ) {
+	return q<Not significant in extended character class>;
+    } elsif ( $self->modifier_asserted( 'x' ) ) {
+	return q<Not significant under /x>;
+    } else {
+	return 'Not significant';
+    }
+}
 
 sub perl_version_introduced {
     my ( $self ) = @_;
@@ -61,46 +90,13 @@ sub can_be_quantified { return };
 # (when scanning for delimiters) or by PPIx::Regexp::Token::Literal (if
 # it hits a match for \s and finds the regular expression has the /x
 # modifier asserted.
-
-=begin comment
-
-sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
-
-    return scalar $tokenizer->find_regexp( qr{ \A \s+ }smx );
-
-}
-
-=end comment
-
-=cut
-
-sub __PPIX_TOKEN__post_make {
-    my ( $self, $tokenizer, $arg ) = @_;
-
-    $self->{perl_version_introduced} = MINIMUM_PERL;
-
-    # RT #91798.
-    # TODO the above needs to be replaced by the following (suitably
-    # modified) when the non-ASCII white space characters are finally
-    # recognized by Perl.
-
-=begin comment
-
-    if ( ord $self->content() < 128 ) {
-	$self->{perl_version_introduced} = MINIMUM_PERL;
-    } elsif ( $tokenizer && $tokenizer->cookie( COOKIE_REGEX_SET ) ) {
-	$self->{perl_version_introduced} = '5.017008';
-    } else {
-	$self->{perl_version_introduced} = '5.017009';
-    }
-
-=end comment
-
-=cut
-
-    return;
-}
+#
+# sub __PPIX_TOKENIZER__regexp {
+#     my ( $class, $tokenizer, $character ) = @_;
+#
+#     return scalar $tokenizer->find_regexp( qr{ \A \s+ }smx );
+#
+# }
 
 1;
 
@@ -117,7 +113,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
