@@ -5,7 +5,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Support };
 
-use Carp qw{ confess };
+use Carp qw{ carp croak confess };
 use PPIx::Regexp::Constant qw{
     MINIMUM_PERL
     TOKEN_LITERAL
@@ -39,10 +39,14 @@ use PPIx::Regexp::Token::Recursion		();
 use PPIx::Regexp::Token::Structure		();
 use PPIx::Regexp::Token::Unknown		();
 use PPIx::Regexp::Token::Whitespace		();
-use PPIx::Regexp::Util qw{ __instance };
+use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.036';
+our $VERSION = '0.047';
+
+our $DEFAULT_POSTDEREF;
+defined $DEFAULT_POSTDEREF
+    or $DEFAULT_POSTDEREF = 0;
 
 {
     # Names of classes containing tokenization machinery. There are few
@@ -56,7 +60,7 @@ our $VERSION = '0.036';
 	'PPIx::Regexp::Token::Interpolation',
 	'PPIx::Regexp::Token::Control',			# Note 1
 	'PPIx::Regexp::Token::CharClass::Simple',	# Note 2
-        'PPIx::Regexp::Token::Quantifier',
+	'PPIx::Regexp::Token::Quantifier',
 	'PPIx::Regexp::Token::Greediness',
 	'PPIx::Regexp::Token::CharClass::POSIX',	# Note 3
 	'PPIx::Regexp::Token::Structure',
@@ -88,46 +92,9 @@ our $VERSION = '0.036';
     #		operators, and Control making them literals if quoting,
     #		so it must come after both.
 
-    sub _known_tokenizers {
-	my ( $self ) = @_;
-
-	my $mode = $self->{mode};
-
-	my @expect;
-	if ( $self->{expect_next} ) {
-	    $self->{expect} = $self->{expect_next};
-	    $self->{expect_next} = undef;
-	}
-	if ( $self->{expect} ) {
-	    @expect = $self->_known_tokenizer_check(
-		@{ $self->{expect} } );
-	}
-
-	exists $self->{known}{$mode} and return (
-	    @expect, @{ $self->{known}{$mode} } );
-
-	my @found = $self->_known_tokenizer_check( @classes );
-
-	$self->{known}{$mode} = \@found;
-	return (@expect, @found);
-    }
-
-    sub _known_tokenizer_check {
-	my ( $self, @args ) = @_;
-
-	my $mode = $self->{mode};
-
-	my $handler = '__PPIX_TOKENIZER__' . $mode;
-	my @found;
-
-	foreach my $class ( @args ) {
-
-	    $class->can( $handler ) or next;
-	    push @found, $class;
-
-	}
-
-	return @found;
+    # Return the declared tokenizer classes.
+    sub __tokenizer_classes {
+	return @classes;
     }
 
 }
@@ -161,7 +128,6 @@ our $VERSION = '0.036';
 	    cursor_modifiers => undef,	# Position of modifiers.
 	    default_modifiers => $args{default_modifiers} || [],
 	    delimiter_finish => undef,	# Finishing delimiter of regexp.
-	    delimiter_re =>	undef,	# Recognize finishing delimiter.
 	    delimiter_start => undef,	# Starting delimiter of regexp.
 	    encoding => $args{encoding}, # Character encoding.
 	    expect => undef,	# Extra classes to expect.
@@ -173,6 +139,9 @@ our $VERSION = '0.036';
 	    mode => 'init',	# Initialize
 	    modifiers => [{}],	# Modifier hash.
 	    pending => [],	# Tokens made but not returned.
+	    postderef => defined $args{postderef} ?
+		$args{postderef} :
+		$DEFAULT_POSTDEREF,
 	    prior => TOKEN_UNKNOWN,	# Prior significant token.
 	    source => $re,	# The object we were initialized with.
 	    trace => __PACKAGE__->_defined_or(
@@ -180,10 +149,20 @@ our $VERSION = '0.036';
 	};
 
 	if ( __instance( $re, 'PPI::Element' ) ) {
-	    $self->{content} = $re->content();
+	    defined( my $tokenizer_class = __choose_tokenizer_class(
+		    $re, { parse => 'guess' } ) )
+		or return __set_errstr( ref $re, 'not supported' );
+	    $class eq $tokenizer_class
+		or return __set_errstr( ref $re, 'not supported by', $class );
+	    # TODO conditionalizstion on PPI class does not really
+	    # belong here, but at the moment I have no other idea of
+	    # where to put it.
+	    $self->{content} = $re->isa( 'PPI::Token::HereDoc' ) ?
+		join( '', $re->content(), "\n", $re->heredoc(),
+		    $re->terminator(), "\n" ) :
+		$re->content();
 	} elsif ( ref $re ) {
-	    $errstr = ref( $re ) . ' not supported';
-	    return;
+	    return __set_errstr( ref $re, 'not supported' );
 	} else {
 	    $self->{content} = $re;
 	}
@@ -192,11 +171,7 @@ our $VERSION = '0.036';
 
 	$self->{content} = $self->decode( $self->{content} );
 
-	if ( $self->{content} =~ m/ \s+ \z /smx ) {
-	    $self->{cursor_limit} = $-[0];
-	} else {
-	    $self->{cursor_limit} = length $self->{content};
-	}
+	$self->{cursor_limit} = length $self->{content};
 
 	$self->{trace}
 	    and warn "\ntokenizing '$self->{content}'\n";
@@ -204,6 +179,11 @@ our $VERSION = '0.036';
 	return $self;
     }
 
+    sub __set_errstr {
+	$errstr = join ' ', @_;
+	return;
+    }
+
     sub errstr {
 	return $errstr;
     }
@@ -284,10 +264,30 @@ sub find_matching_delimiter {
     my $inx = $self->{cursor_curr};
     my $finish = (
 	my $bracketed = $self->close_bracket( $start ) ) || $start;
+
+=begin comment
+
+    $self->{trace}
+	and warn "Find matching delimiter: Start with '$start' at $self->{cursor_curr}, end with '$finish' at or before $self->{cursor_limit}\n";
+
+=end comment
+
+=cut
+
     my $nest = 0;
 
     while ( ++$inx < $self->{cursor_limit} ) {
 	my $char = substr $self->{content}, $inx, 1;
+
+=begin comment
+
+	$self->{trace}
+	    and warn "    looking at '$char' at $inx, nest level $nest\n";
+
+=end comment
+
+=cut
+
 	if ( $char eq '\\' && $finish ne '\\' ) {
 	    ++$inx;
 	} elsif ( $bracketed && $char eq $start ) {
@@ -338,6 +338,11 @@ sub find_regexp {
     return wantarray ? ( $-[0] + 0, $+[0] + 0 ) : $+[0] + 0;
 }
 
+sub get_mode {
+    my ( $self ) = @_;
+    return $self->{mode};
+}
+
 sub get_start_delimiter {
     my ( $self ) = @_;
     return $self->{delimiter_start};
@@ -352,13 +357,22 @@ sub get_token {
 
     my $handler = '__PPIX_TOKENIZER__' . $self->{mode};
 
+    my $code = $self->can( $handler )
+	or confess "Getting token in mode '$self->{mode}'. ",
+	    "cursor_curr = $self->{cursor_curr}; ",
+	    "cursor_limit = $self->{cursor_limit}; ",
+	    "length( content ) = ", length $self->{content};
+
     my $character = substr(
 	$self->{content},
 	$self->{cursor_curr},
 	1
     );
 
-    return ( __PACKAGE__->$handler( $self, $character ) );
+    $self->{trace}
+	and warn "get_token() got '$character' from $self->{cursor_curr}\n";
+
+    return ( $code->( $self, $character ) );
 }
 
 sub interpolates {
@@ -387,9 +401,13 @@ sub make_token {
     $self->{trace} > 1
 	and warn "    make_token: cursor_curr = $self->{cursor_curr}; ",
 	    "cursor_limit = $self->{cursor_limit}\n";
-    my $token = $class->_new( $content ) or return;
-    $token->significant() and $self->{expect} = undef;
-    $token->__PPIX_TOKEN__post_make( $self, $arg );
+    my $token = $class->__new( $content,
+	tokenizer	=> $self,
+	%{ $arg || {} } )
+	or return;
+
+    $token->significant()
+	and $self->{expect} = undef;
 
     $token->isa( TOKEN_UNKNOWN ) and $self->{failures}++;
 
@@ -408,7 +426,7 @@ sub make_token {
     # do this after processing cookies, so that the cookies have access
     # to the old token if they want.
     $token->significant()
-	and $self->{prior} = $token;
+	and $self->{prior_significant_token} = $token;
 
     return $token;
 }
@@ -420,7 +438,8 @@ sub match {
 
 sub modifier {
     my ( $self, $modifier ) = @_;
-    return $self->{modifiers}[-1]{$modifier};
+    return PPIx::Regexp::Token::Modifier::__asserts(
+	$self->{modifiers}[-1], $modifier );
 }
 
 sub modifier_duplicate {
@@ -462,8 +481,8 @@ sub next_token {
 	    $self->{cursor_limit} >= length $self->{content}
 		and return;
 	    $self->{mode} eq 'finish' and return;
-	    $self->{mode} = 'finish';
-	    $self->{cursor_limit}++;
+	    $self->_set_mode( 'finish' );
+	    $self->{cursor_limit} += length $self->{delimiter_finish};
 	}
 
 	if ( my @tokens = $self->get_token() ) {
@@ -497,18 +516,188 @@ sub ppi_document {
 
 sub prior {
     my ( $self, $method, @args ) = @_;
-    defined $method or return $self->{prior};
-    $self->{prior}->can( $method )
+    $self->_deprecation_notice( method => 'prior',
+	'prior_significant_token()' );
+    defined $method or return $self->{prior_significant_token};
+    $self->{prior_significant_token}->can( $method )
 	or confess 'Programming error - ',
-	    ( ref $self->{prior} || $self->{prior} ),
+	    ( ref $self->{prior_significant_token} ||
+		$self->{prior_significant_token} ),
 	    ' does not support method ', $method;
-    return $self->{prior}->$method( @args );
+    return $self->{prior_significant_token}->$method( @args );
+}
+
+sub prior_significant_token {
+    my ( $self, $method, @args ) = @_;
+    defined $method or return $self->{prior_significant_token};
+    $self->{prior_significant_token}->can( $method )
+	or confess 'Programming error - ',
+	    ( ref $self->{prior_significant_token} ||
+		$self->{prior_significant_token} ),
+	    ' does not support method ', $method;
+    return $self->{prior_significant_token}->$method( @args );
+}
+
+# my $length = $token->__recognize_postderef( $tokenizer, $iterator ).
+#
+# This method is private to the PPIx-Regexp package, and may be changed
+# or retracted without warning. What it does is to recognize postfix
+# dereferences. It returns the length in characters of the first postfix
+# dereference found, or a false value if none is found. This returns
+# false immediately unless the tokenizer was instantiated with the
+# C<postderef> argument true, or if it was not specified and
+# C<$DEFAULT_POSTDEREF> was true when the tokenizer was instantiated.
+#
+# The optional $iterator argument can be one of the following:
+#   - A code reference, which will be called to provide PPI::Element
+#     objects to be checked to see if they represent a postfix
+#     dereference.
+#   - A PPI::Element, which is checked to see if it is a postfix
+#     dereference.
+#   - Undef, or omitted, in which case ppi() is called on the invocant,
+#     and everything that follows the '->' operator is checked to see if
+#     it is a postfix dereference.
+#   - Anything else results in an exception and stack trace.
+
+{
+    # %* &* **
+    my %magic_var = map { $_ => 1 } qw{ @* $* };
+    my %magic_oper = map { $_ => 1 } qw{ & ** % };
+    my %sliceable = map { $_ => 1 } qw{ @ % };
+    my %post_slice = map { $_ => 1 } qw< { [ >;	# ] }
+
+    sub __recognize_postderef {
+	my ( $self, $token, $iterator ) = @_;
+	$self->{postderef}
+	    or return;
+	# Note that if ppi() gets called I have to hold a reference to
+	# the returned object until I am done with all its children.
+	my $ppi;
+	if ( ! defined $iterator ) {
+	    $ppi = $token->ppi();
+	    my @ops = grep { '->' eq $_->content() } @{
+		$ppi->find( 'PPI::Token::Operator' ) || [] };
+	    $iterator = sub {
+		my $op = shift @ops
+		    or return;
+		return $op->snext_sibling();
+	    };
+	} elsif ( $iterator->isa( 'PPI::Element' ) ) {
+	    my @eles = ( $iterator );
+	    $iterator = sub {
+		return shift @eles;
+	    };
+	} elsif ( 'CODE' ne ref $iterator ) {
+	    confess 'Programming error - Iterator not understood';
+	}
+
+	my $accept = $token->__postderef_accept_cast();
+
+	while ( my $elem = $iterator->() ) {
+
+	    my $content = $elem->content();
+	    $content =~ m/ \A ( . \#? ) /smx
+		and $accept->{$1}
+		or next;
+
+	    my $length = length $content;
+
+	    # PPI parses '$x->@*' as containing magic variable '@*'.
+	    # Similarly for '$*' and '$#*'. I think this is a bug, and
+	    # they should be parsed as casts, but ...
+	    if ( $elem->isa( 'PPI::Token::Magic' ) ) {
+		$magic_var{$content}
+		    and return $length;
+		if ( '$#' eq $content ) {
+		    my $next = $elem->snext_sibling()
+			or return $length;
+		    '*' eq substr $next->content(), 0, 1
+			and return $length + 1;
+		}
+	    }
+
+	    # PPI parses '%*' as a cast of '%' followed by a splat, but
+	    # I think it is likely that if it ever supports postderef
+	    # operators that they will be casts. It currently parses
+	    # '**' as an operator and '&*' as two operators, but the
+	    # logic is pretty much the same as for a cast, so they get
+	    # handled here too.
+	    if ( $elem->isa( 'PPI::Token::Cast' ) || $elem->isa(
+		    'PPI::Token::Operator' ) && $magic_oper{$content} ) {
+		# Maybe PPI will eventually parse something like '$*' as
+		# a cast, so ...
+		$content =~ m/ [*] \z /smx
+		    and return $length;
+		# Or maybe it will parse the asterisk separately, but I
+		# have no idea what its class will be.
+		my $next = $elem->snext_sibling()
+		    or return;
+		my $next_content = $next->content();
+		my $next_char = substr $next_content, 0, 1;
+		'*' eq $next_char
+		    and return $length + 1;
+		# We may still have a slice.
+		$sliceable{$content}
+		    and $post_slice{$next_char}
+		    and return $length + length $next_content;
+		# TODO maybe PPI will do something completely
+		# unanticipated with postderef.
+	    }
+
+	    # Otherwise, we're not a postfix dereference; try the next
+	    # iteration.
+	}
+
+	# No postfix dereference found.
+	return;
+    }
 }
 
 sub significant {
     return 1;
 }
 
+sub _known_tokenizers {
+    my ( $self ) = @_;
+
+    my $mode = $self->{mode};
+
+    my @expect;
+    if ( $self->{expect_next} ) {
+	$self->{expect} = $self->{expect_next};
+	$self->{expect_next} = undef;
+    }
+    if ( $self->{expect} ) {
+	@expect = $self->_known_tokenizer_check(
+	    @{ $self->{expect} } );
+    }
+
+    exists $self->{known}{$mode} and return (
+	@expect, @{ $self->{known}{$mode} } );
+
+    my @found = $self->_known_tokenizer_check(
+	$self->__tokenizer_classes() );
+
+    $self->{known}{$mode} = \@found;
+    return (@expect, @found);
+}
+
+sub _known_tokenizer_check {
+    my ( $self, @args ) = @_;
+
+    my $handler = '__PPIX_TOKENIZER__' . $self->{mode};
+    my @found;
+
+    foreach my $class ( @args ) {
+
+	$class->can( $handler ) or next;
+	push @found, $class;
+
+    }
+
+    return @found;
+}
+
 sub tokens {
     my ( $self ) = @_;
 
@@ -520,6 +709,62 @@ sub tokens {
     return @rslt;
 }
 
+#	$self->_deprecation_notice( $type, $name );
+#
+#	This method centralizes deprecation. Type is 'attribute' or
+#	'method'. Deprecation is driven of the %deprecate hash. Values
+#	are:
+#	    false - no warning
+#	    1 - warn on first use
+#	    2 - warn on each use
+#	    3 - die on each use.
+#
+#	$self->_deprecation_in_progress( $type, $name )
+#
+#	This method returns true if the deprecation is in progress. In
+#	fact it returns the deprecation level.
+
+{
+
+    my %deprecate = (
+	attribute => {
+	},
+	method => {
+	    prior	=> 0,
+	},
+    );
+
+    sub _deprecation_notice {
+	my ( undef, $type, $name, $repl ) = @_;		# Invocant unused
+	$deprecate{$type} or return;
+	$deprecate{$type}{$name} or return;
+	my $msg = sprintf 'The %s %s is %s', $name, $type,
+	    $deprecate{$type}{$name} > 2 ? 'removed' : 'deprecated';
+	defined $repl
+	    and $msg .= "; use $repl instead";
+	$deprecate{$type}{$name} >= 3
+	    and croak $msg;
+	warnings::enabled( 'deprecated' )
+	    and carp $msg;
+	$deprecate{$type}{$name} == 1
+	    and $deprecate{$type}{$name} = 0;
+	return;
+    }
+
+=begin comment
+
+    sub _deprecation_in_progress {
+	my ( $self, $type, $name ) = @_;
+	$deprecate{$type} or return;
+	return $deprecate{$type}{$name};
+    }
+
+=end comment
+
+=cut
+
+}
+
 sub _remainder {
     my ( $self ) = @_;
 
@@ -534,91 +779,233 @@ sub _remainder {
     return;
 }
 
+sub _make_final_token {
+    my ( $self, $len, $class, $arg ) = @_;
+    my $token = $self->make_token( $len, $class, $arg );
+    $self->_set_mode( 'kaput' );
+    return $token;
+}
+
+sub _set_mode {
+    my ( $self, $mode ) = @_;
+    $self->{mode} = $mode;
+    if ( 'kaput' eq $mode ) {
+	$self->{cursor_curr} = $self->{cursor_limit} =
+	    length $self->{content};
+    }
+    return;
+}
+
+sub __init_error {
+    my ( $self , $err ) = @_;
+    defined $err
+	or $err = 'Tokenizer found illegal first characters';
+    return $self->_make_final_token(
+	length $self->{content}, TOKEN_UNKNOWN, {
+	    error	=> $err,
+	},
+    );
+}
+
 sub __PPIX_TOKENIZER__init {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( $self ) = @_;
 
-    $tokenizer->{mode} = 'kaput';
-    $tokenizer->{content} =~ m/ \A \s* ( qr | m | s )? ( \s* ) ( [^\w\s] ) /smx
-	or return $tokenizer->make_token(
-	    length( $tokenizer->{content} ), TOKEN_UNKNOWN, {
-		error	=> 'Tokenizer found illegal first characters',
-	    },
-	);
-#   my ( $type, $white, $delim ) = ( $1, $2, $3 );
-    my ( $type, $white ) = ( $1, $2 );
-    my $start_pos = defined $-[1] ? $-[1] :
-	defined $-[2] ? $-[2] :
-	defined $-[3] ? $-[3] : 0;
+    $self->find_regexp(
+	qr{ \A ( \s* ) ( qr | m | s )? ( \s* ) (?: [^\w\s] ) }smx )
+	or return $self->__init_error();
 
-    defined $type or $type = '';
-    $tokenizer->{type} = $type;
+    my ( $leading_white, $type, $next_white ) = $self->capture();
+
+    defined $type
+	or $type = '';
+
+    $self->{type} = $type;
 
     my @tokens;
-    $start_pos
-	and push @tokens, $tokenizer->make_token( $start_pos,
+
+    '' ne $leading_white
+	and push @tokens, $self->make_token( length $leading_white,
 	'PPIx::Regexp::Token::Whitespace' );
-    push @tokens, $tokenizer->make_token( length $type,
+    push @tokens, $self->make_token( length $type,
 	'PPIx::Regexp::Token::Structure' );
-    length $white > 0
-	and push @tokens, $tokenizer->make_token( length $white,
+    '' ne $next_white
+	and push @tokens, $self->make_token( length $next_white,
 	'PPIx::Regexp::Token::Whitespace' );
 
+    $self->{delimiter_start} = substr
+	$self->{content},
+	$self->{cursor_curr},
+	1;
+
+    $self->{trace}
+	and warn "Tokenizer found regexp start delimiter '$self->{delimiter_start}' at $self->{cursor_curr}\n";
+
+    if ( my $offset = $self->find_matching_delimiter() ) {
+	my $cursor_limit = $self->{cursor_curr} + $offset;
+	$self->{trace}
+	    and warn "Tokenizer found regexp end delimiter at $cursor_limit\n";
+	if ( $self->__number_of_extra_parts() ) {
+	    if ( $self->close_bracket(
+		    $self->{delimiter_start} ) ) {
+		pos $self->{content} = $self->{cursor_curr} +
+		$offset + 1;
+		$self->{content} =~ m/ \s* /smxgc;
+	    } else {
+		pos $self->{content} = $self->{cursor_curr} +
+		$offset;
+	    }
+	    local $self->{cursor_curr} = pos $self->{content};
+	    local $self->{delimiter_start} = substr
+		$self->{content},
+		$self->{cursor_curr},
+		1;
+	    $self->{trace}
+		and warn "Tokenizer found replacement start delimiter '$self->{delimiter_start}' at $self->{cursor_curr}\n";
+	    if ( my $s_off = $self->find_matching_delimiter() ) {
+		$self->{cursor_modifiers} =
+		    $self->{cursor_curr} + $s_off + 1;
+		$self->{trace}
+		    and warn "Tokenizer found replacement end delimiter at @{[
+			$self->{cursor_curr} + $s_off ]}\n";
+	    } else {
+		$self->{cursor_curr} = 0;
+		return $self->_make_final_token(
+		    length( $self->{content} ), TOKEN_UNKNOWN, {
+			error	=> 'Tokenizer found mismatched replacement delimiters',
+		    },
+		);
+	    }
+	} else {
+	    $self->{cursor_modifiers} = $cursor_limit + 1;
+	}
+	$self->{cursor_limit} = $cursor_limit;
+    } else {
+	$self->{cursor_curr} = 0;
+	return $self->_make_final_token(
+	    length( $self->{content} ), TOKEN_UNKNOWN, {
+		error	=> 'Tokenizer found mismatched regexp delimiters',
+	    },
+	);
+    }
+
     {
-	my @mods = @{ $tokenizer->{default_modifiers} };
-	if ( $tokenizer->{content} =~ m/ ( [[:lower:]]* ) \s* \z /smx ) {
-	    my $mod = $1;
-	    $tokenizer->{cursor_limit} -= length $mod;
-	    push @mods, $mod;
+	my @mods = @{ $self->{default_modifiers} };
+	pos $self->{content} = $self->{cursor_modifiers};
+	local $self->{cursor_curr} = $self->{cursor_modifiers};
+	local $self->{cursor_limit} = length $self->{content};
+	my @trailing;
+	{
+	    my $len = $self->find_regexp( qr{ \A [[:lower:]]* }smx );
+	    push @trailing, $self->make_token( $len,
+		'PPIx::Regexp::Token::Modifier' );
 	}
-	$tokenizer->{effective_modifiers} =
+	if ( my $len = $self->find_regexp( qr{ \A \s+ }smx ) ) {
+	    push @trailing, $self->make_token( $len,
+		'PPIx::Regexp::Token::Whitespace' );
+	}
+	if ( my $len = $self->find_regexp( qr{ \A .+ }smx ) ) {
+	    push @trailing, $self->make_token( $len, TOKEN_UNKNOWN, {
+		    error	=> 'Trailing characters after expression',
+		} );
+	}
+	$self->{trailing_tokens} = \@trailing;
+	push @mods, $trailing[0]->content();
+	$self->{effective_modifiers} =
 	    PPIx::Regexp::Token::Modifier::__aggregate_modifiers (
 		@mods );
-	$tokenizer->{modifiers} = [
-	    { %{ $tokenizer->{effective_modifiers} } },
+	$self->{modifiers} = [
+	    { %{ $self->{effective_modifiers} } },
 	];
-	$tokenizer->{cursor_modifiers} = $tokenizer->{cursor_limit};
     }
 
-    $tokenizer->{delimiter_start} = substr
-	$tokenizer->{content},
-	$tokenizer->{cursor_curr},
+    $self->{delimiter_finish} = substr
+	$self->{content},
+	$self->{cursor_limit},
 	1;
 
-    if ( $type eq 's' and my $offset = $tokenizer->find_matching_delimiter() ) {
-	$tokenizer->{cursor_limit} = $tokenizer->{cursor_curr} + $offset;
-    } else {
-	$tokenizer->{cursor_limit} = $tokenizer->{cursor_modifiers} - 1;
-    }
-
-    $tokenizer->{delimiter_finish} = substr
-	$tokenizer->{content},
-	$tokenizer->{cursor_limit},
-	1;
-    $tokenizer->{delimiter_re} = undef;
-
-    push @tokens, $tokenizer->make_token( 1,
+    push @tokens, $self->make_token( 1,
 	'PPIx::Regexp::Token::Delimiter' );
 
-    $tokenizer->{mode} = 'regexp';
+    $self->_set_mode( 'regexp' );
+
+    $self->{find} = undef;
 
     return @tokens;
 }
 
-sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+# Match the initial part of the regexp including any leading white
+# space. The initial delimiter is the first thing not consumed, though
+# we check it for sanity.
+sub __initial_match {
+    my ( $self ) = @_;
 
-    my $mode = $tokenizer->{mode};
+    $self->find_regexp(
+	qr{ \A ( \s* ) ( qr | m | s )? ( \s* ) (?: [^\w\s] ) }smx )
+	or return;
+
+    my ( $leading_white, $type, $next_white ) = $self->capture();
+
+    defined $type
+	or $type = '';
+
+    $self->{type} = $type;
+
+    my @tokens;
+
+    '' ne $leading_white
+	and push @tokens, $self->make_token( length $leading_white,
+	'PPIx::Regexp::Token::Whitespace' );
+    push @tokens, $self->make_token( length $type,
+	'PPIx::Regexp::Token::Structure' );
+    '' ne $next_white
+	and push @tokens, $self->make_token( length $next_white,
+	'PPIx::Regexp::Token::Whitespace' );
+
+    return @tokens;
+}
+
+{
+    my %extra_parts = (
+	s	=> 1,
+    );
+
+    # Return the number of extra delimited parts. This will be 0 except
+    # for s///, which will be 1.
+    sub __number_of_extra_parts {
+	my ( $self ) = @_;
+	return $extra_parts{$self->{type}} || 0;
+    }
+}
+
+{
+    my @part_class = qw{
+	PPIx::Regexp::Structure::Regexp
+	PPIx::Regexp::Structure::Replacement
+    };
+
+    # Return the classes for the parts of the expression.
+    sub __part_classes {
+	my ( $self ) = @_;
+	my $max = $self->__number_of_extra_parts();
+	return @part_class[ 0 .. $max ];
+    }
+}
+
+sub __PPIX_TOKENIZER__regexp {
+    my ( $self, $character ) = @_;
+
+    my $mode = $self->{mode};
     my $handler = '__PPIX_TOKENIZER__' . $mode;
 
-    $tokenizer->{cursor_orig} = $tokenizer->{cursor_curr};
-    foreach my $class( $tokenizer->_known_tokenizers() ) {
-	my @tokens = grep { $_ } $class->$handler( $tokenizer, $character );
-	$tokenizer->{trace}
-	    and warn $class, "->$handler( \$tokenizer, '$character' )",
+    $self->{cursor_orig} = $self->{cursor_curr};
+    foreach my $class ( $self->_known_tokenizers() ) {
+	my @tokens = grep { $_ } $class->$handler( $self, $character );
+	$self->{trace}
+	    and warn $class, "->$handler( \$self, '$character' )",
 		" => (@tokens)\n";
 	@tokens
 	    and return ( map {
-		ref $_ ? $_ : $tokenizer->make_token( $_,
+		ref $_ ? $_ : $self->make_token( $_,
 		    $class ) } @tokens );
     }
 
@@ -626,121 +1013,106 @@ sub __PPIX_TOKENIZER__regexp {
     my $fallback = __PACKAGE__->can( '__PPIX_TOKEN_FALLBACK__' . $mode )
 	|| __PACKAGE__->can( '__PPIX_TOKEN_FALLBACK__regexp' )
 	|| confess "Programming error - unable to find fallback for $mode";
-    return $fallback->( $class, $tokenizer, $character );
+    return $fallback->( $self, $character );
 }
 
 *__PPIX_TOKENIZER__repl = \&__PPIX_TOKENIZER__regexp;
 
 sub __PPIX_TOKEN_FALLBACK__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( $self, $character ) = @_;
 
     # As a fallback in regexp mode, any escaped character is a literal.
     if ( $character eq '\\'
-	&& $tokenizer->{cursor_limit} - $tokenizer->{cursor_curr} > 1
+	&& $self->{cursor_limit} - $self->{cursor_curr} > 1
     ) {
-	return $tokenizer->make_token( 2, TOKEN_LITERAL );
+	return $self->make_token( 2, TOKEN_LITERAL );
     }
 
     # Any normal character is unknown.
-    return $tokenizer->make_token( 1, TOKEN_UNKNOWN, {
+    return $self->make_token( 1, TOKEN_UNKNOWN, {
 	    error	=> 'Tokenizer found unexpected literal',
 	},
     );
 }
 
 sub __PPIX_TOKEN_FALLBACK__repl {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( $self, $character ) = @_;
 
     # As a fallback in replacement mode, any escaped character is a literal.
     if ( $character eq '\\'
-	&& defined ( my $next = $tokenizer->peek( 1 ) ) ) {
+	&& defined ( my $next = $self->peek( 1 ) ) ) {
 
-	if ( $tokenizer->interpolates() || $next eq q<'> || $next eq '\\' ) {
-	    return $tokenizer->make_token( 2, TOKEN_LITERAL );
+	if ( $self->interpolates() || $next eq q<'> || $next eq '\\' ) {
+	    return $self->make_token( 2, TOKEN_LITERAL );
 	}
-	return $tokenizer->make_token( 1, TOKEN_LITERAL );
+	return $self->make_token( 1, TOKEN_LITERAL );
     }
 
     # So is any normal character.
-    return $tokenizer->make_token( 1, TOKEN_LITERAL );
+    return $self->make_token( 1, TOKEN_LITERAL );
 }
 
 sub __PPIX_TOKENIZER__finish {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( $self ) = @_;		# $character unused
 
-    $tokenizer->{cursor_limit} > length $tokenizer->{content}
+    $self->{cursor_limit} > length $self->{content}
 	and confess "Programming error - ran off string";
-    my @tokens = $tokenizer->make_token( 1,
+
+    my @tokens = $self->make_token( length $self->{delimiter_finish},
 	'PPIx::Regexp::Token::Delimiter' );
 
-    if ( $tokenizer->{cursor_curr} eq $tokenizer->{cursor_modifiers} ) {
+    if ( $self->{cursor_curr} == $self->{cursor_modifiers} ) {
 
-	# We are out of string. Make the modifier token and close up
-	# shop.
-	my $trailer;
-	if ( $tokenizer->{content} =~ m/ \s+ \z /smx ) {
-	    $tokenizer->{cursor_limit} = $-[0];
-	    $trailer = length( $tokenizer->{content} ) -
-		$tokenizer->{cursor_curr};
-	} else {
-	    $tokenizer->{cursor_limit} = length $tokenizer->{content};
-	}
-	push @tokens, $tokenizer->make_token(
-	    $tokenizer->{cursor_limit} - $tokenizer->{cursor_curr},
-	    'PPIx::Regexp::Token::Modifier' );
-	if ( $trailer ) {
-	    $tokenizer->{cursor_limit} = length $tokenizer->{content};
-	    push @tokens, $tokenizer->make_token(
-		$trailer, 'PPIx::Regexp::Token::Whitespace' );
-	}
-	$tokenizer->{mode} = 'kaput';
+	# We are out of string. Add the trailing tokens (created when we
+	# did the initial bracket scan) and close up shop.
+
+	push @tokens, @{ delete $self->{trailing_tokens} };
+
+	$self->_set_mode( 'kaput' );
 
     } else {
 
 	# Clear the cookies, because we are going around again.
-	$tokenizer->{cookie} = {};
+	$self->{cookie} = {};
 
 	# Move the cursor limit to just before the modifiers.
-	$tokenizer->{cursor_limit} = $tokenizer->{cursor_modifiers} - 1;
+	$self->{cursor_limit} = $self->{cursor_modifiers} - 1;
 
 	# If the preceding regular expression was bracketed, we need to
 	# consume possible whitespace and find another delimiter.
 
-	if ( $tokenizer->close_bracket( $tokenizer->{delimiter_start} ) ) {
+	if ( $self->close_bracket( $self->{delimiter_start} ) ) {
 	    my $accept;
-	    $accept = $tokenizer->find_regexp( qr{ \A \s+ }smx )
-		and push @tokens, $tokenizer->make_token(
+	    $accept = $self->find_regexp( qr{ \A \s+ }smx )
+		and push @tokens, $self->make_token(
 		$accept, 'PPIx::Regexp::Token::Whitespace' );
-	    my $character = $tokenizer->peek();
-	    $tokenizer->{delimiter_start} = $character;
-	    push @tokens, $tokenizer->make_token(
+	    my $character = $self->peek();
+	    $self->{delimiter_start} = $character;
+	    push @tokens, $self->make_token(
 		1, 'PPIx::Regexp::Token::Delimiter' );
-	    $tokenizer->{delimiter_finish} = substr
-		$tokenizer->{content},
-		$tokenizer->{cursor_limit} - 1,
+	    $self->{delimiter_finish} = substr
+		$self->{content},
+		$self->{cursor_limit} - 1,
 		1;
-	    $tokenizer->{delimiter_re} = undef;
 	}
 
-	if ( $tokenizer->modifier( 'e' ) ) {
-	    # With /e, the replacement portion is code. We make it all
-	    # into one big PPIx::Regexp::Token::Code, slap on the
+	if ( $self->modifier( 'e*' ) ) {
+	    # With /e or /ee, the replacement portion is code. We make
+	    # it all into one big PPIx::Regexp::Token::Code, slap on the
 	    # trailing delimiter and modifiers, and return it all.
-	    push @tokens, $tokenizer->make_token(
-		$tokenizer->{cursor_limit} - $tokenizer->{cursor_curr},
+	    push @tokens, $self->make_token(
+		$self->{cursor_limit} - $self->{cursor_curr},
 		'PPIx::Regexp::Token::Code',
 		{ perl_version_introduced => MINIMUM_PERL },
 	    );
-	    $tokenizer->{cursor_limit} = length $tokenizer->{content};
-	    push @tokens, $tokenizer->make_token( 1,
-		'PPIx::Regexp::Token::Delimiter' );
-	    push @tokens, $tokenizer->make_token(
-		$tokenizer->{cursor_limit} - $tokenizer->{cursor_curr},
-		'PPIx::Regexp::Token::Modifier' );
-	    $tokenizer->{mode} = 'kaput';
+	    $self->{cursor_limit} = length $self->{content};
+	    push @tokens, $self->make_token( 1,
+		'PPIx::Regexp::Token::Delimiter' ),
+		@{ delete $self->{trailing_tokens} };
+	    $self->_set_mode( 'kaput' );
 	} else {
 	    # Put our mode to replacement.
-	    $tokenizer->{mode} = 'repl';
+	    $self->_set_mode( 'repl' );
 	}
 
     }
@@ -806,6 +1178,14 @@ This option specifies the encoding of the string to be tokenized. If
 specified, an C<Encode::decode> is done on the string (or the C<content>
 of the PPI class) before it is tokenized.
 
+=item postderef boolean
+
+This option specifies whether the tokenizer recognizes postfix
+dereferencing. See the L<PPIx::Regexp|PPIx::Regexp>
+L<new()|PPIx::Regexp/new> documentation for the details.
+
+C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF> is not exported.
+
 =item trace number
 
 Specifying a positive value for this option causes a trace of the
@@ -870,6 +1250,13 @@ L<PPIx::Regexp::Token::Unknown|PPIx::Regexp::Token::Unknown>.
 This method returns true if the given modifier character was found on
 the end of the regular expression, and false otherwise.
 
+Starting with version 0.036_01, if the argument is a
+single-character modifier followed by an asterisk (intended as a wild
+card character), the return is the number of times that modifier
+appears. In this case an exception will be thrown if you specify a
+multi-character modifier (e.g.  C<'ee*'>), or if you specify one of the
+match semantics modifiers (e.g.  C<'a*'>).
+
 =head2 next_token
 
  my $token = $tokenizer->next_token();
@@ -1005,6 +1392,10 @@ This method returns the offset from the current position in the content
 string to the matching delimiter (which will always be positive), or
 undef if no match can be found.
 
+=head2 get_mode
+
+This method returns the name of the current mode of the tokenizer.
+
 =head2 get_start_delimiter
 
  my $start_delimiter = $tokenizer->get_start_delimiter();
@@ -1121,6 +1512,15 @@ returns it.
  $tokenizer->prior( 'can_be_quantified' )
     and print "The prior token can be quantified.\n";
 
+This method is deprecated in favor of
+L<prior_significant_tokrn()|/prior_significant_token>. Six months after
+the release of version 0.044_01 it will start warning on the
+first use. Six months after that it will warn on every use. Six months
+after that a fatal exception will be thrown when it is called. I am not
+sure I need to put this though a deprecation cycle, given that this
+method is documented as not being part of the public interface, but I
+choose to err on the side of caution.
+
 This method calls the named method on the most-recently-instantiated
 significant token, and returns the result. Any arguments subsequent to
 the method name will be passed to the method.
@@ -1128,6 +1528,24 @@ the method name will be passed to the method.
 Because this method is designed to be used within the tokenizing system,
 it will die horribly if the named method does not exist.
 
+If called with no arguments at all the most-recently-instantiated
+significant token is returned.
+
+=head2 prior_significant_token
+
+ $tokenizer->prior_significant_token( 'can_be_quantified' )
+    and print "The prior token can be quantified.\n";
+
+This method calls the named method on the most-recently-instantiated
+significant token, and returns the result. Any arguments subsequent to
+the method name will be passed to the method.
+
+Because this method is designed to be used within the tokenizing system,
+it will die horribly if the named method does not exist.
+
+If called with no arguments at all the most-recently-instantiated
+significant token is returned.
+
 =head1 ENVIRONMENT VARIABLES
 
 A tokenizer trace can be requested by setting environment variable
@@ -1150,7 +1568,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
